import asyncio
import json
import os
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText

import aiosmtplib
from azure.servicebus.aio import ServiceBusClient

CONNECTION_STR = os.environ['SERVICEBUS_CONNECTION_STR']
QUEUE_NAME = os.environ["SERVICEBUS_QUEUE_NAME"]

async def run(loop,logger=None):
    servicebus_client = ServiceBusClient.from_connection_string(conn_str=CONNECTION_STR)
    while True:
        print("waiting message...")
        async with servicebus_client:
            receiver = servicebus_client.get_queue_receiver(queue_name=QUEUE_NAME)
            async with receiver:
                received_msgs = await receiver.receive_messages(max_message_count=10, max_wait_time=1)
                for msg in received_msgs:
                    mail = {}
                    try:
                        mail = json.loads(str(msg))
                    except:
                        print(str(msg))
                        continue;
                    print(str(mail))
                    asyncio.create_task(send_email(mail))
                    await receiver.complete_message(msg)

async def send_email(mail):
    try:
        async with aiosmtplib.SMTP(hostname=mail["smtp"]["server"], port=mail["smtp"]["port"]) as smtp:
            email = MIMEMultipart('alternative')
            email["From"] = mail['sender']
            email["To"] = mail['receiver']
            if('bcc' in mail and mail['bcc']):
                email["BCC"] = mail['bcc']
            if('cc' in mail and mail['cc']):
                email["CC"] = mail['cc']
            email["Subject"] = mail['subject']
            email.attach(MIMEText(mail['message'], "html"))
            await aiosmtplib.send(email, hostname=mail["smtp"]["server"], port=mail["smtp"]["port"],username=mail["smtp"]["username"],password=mail["smtp"]["password"])

    except Exception as e:
        print("Error:", e)


import setuptools

setuptools.setup(
    name="modulairy-mail-sender",
    version="0.0.2.1",
    author="Fatih Mehmet ARSLAN",
    author_email="contact@fmarslan.com",
    description="This script enables sending emails asynchronously from Azure Service Bus. Each bus message contains a sender's email address along with SMTP configurations. The script utilizes its SMTP configuration of the message for sending emails.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    platforms="all",
    url="https://github.com/modulairy/mail-sender",
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Topic :: Internet",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries",
        "Intended Audience :: Developers",
        "Operating System :: MacOS",
        "Operating System :: POSIX",
        "Operating System :: Microsoft",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8"
    ],
    install_requires=["aiosmtplib","azure-servicebus"],
    python_requires=">=3.8, <4",
    packages=['modulairy_mail_sender'],
    scripts=['bin/modulairy-mail-sender']
)
